llrconfig - Manage the LoadLeveler configuration

Use the llrconfig command to manage LoadLeveler's configuration
database.


Syntax


To initialize the LoadLeveler database configuration: 

llrconfig
         -? | -H | -v | -i [-q] [-f config_file_list] [-t
         cluster_configuration_file]


To work with configuration keywords in the database configuration: 

llrconfig
         [-h hostlist] { -d keywords ... | [-N] -c keyword=value ... }


To work with administration stanzas and keywords in the database
configuration: 

llrconfig
         -s { -d stanza[= value[:substanza] ] | [-N] { {-a | -r}
         stanza=value[:substanza] | -a -f stanza_file | -c
         stanza=value[:substanza] keyword1=value1... } }


Flags


-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-i 
   Initializes the configuration database using default LoadLeveler
   configuration files or the LoadLeveler configuration files specified
   by the -f flag. This flag can be used with the -f or -t flag.

-q 
   Specifies no prompting with the -i option.

-f config_file_list
   Is a blank-delimited list of full path names of configuration files
   that are used to initialize the database when used in conjunction
   with the -i flag. You can specify a list of configuration files with
   the -f flag when used in conjunction with the -i flag; however, if a
   keyword is specified in more than one file, the last value is used.
   Administration files cannot be specified in the list, but the last
   value for the ADMIN_FILE specified in a file in the config_file_list
   will be used to initialize the database.

-f stanza_file
   Is the name of a file containing administration stanzas to be added
   to the database when used in conjunction with the -s flag. You can
   only specify one stanza file with the -f flag when used in
   conjunction with the -s flag. 

   The stanza_file has the same format as the administration file and it
   can contain multiple different stanzas.

-t cluster_configuration_file
   Specifies the full path name of an xCAT cluster configuration file
   used to supply LoadLeveler cluster information to initialize the
   database. This flag can only be used with the -i flag.

-h hostlist
   Is a blank-delimited list of machines. You can only specify the -h
   flag if you are using the -c and -d flags to change or display the
   keywords of these machines. The -h flag is not valid when -s is used.

-d keywords ...
   Displays the values of the keywords in a blank-delimited list for the
   global or default machine, or for machines specified with the -h
   flag. If the value of a keyword cannot be displayed, an error message
   will be printed and the command continues to display the value of the
   next keyword.

-d stanza[= value[:substanza]]
   When used with -s, displays the values of the stanza names or stanza
   attributes. In stanza mode, all instances of a specified stanza type,
   for instance all class stanza names, are displayed or a specific
   stanza or substanza, such as class=large, is displayed. Values that
   come from defaults will not be listed. Only values that have been
   defined for this stanza will be displayed.

-N 
   Specifies do not reconfigure LoadLeveler after the update is made to
   the database.

-c keyword=value ...
   Changes a keyword value to the new value provided. One or more
   strings in a format similar to keyword=value must be specified with
   the -c flag. The change applies to machines specified by the -h flag
   or if a machine is not specified, the change applies to the global or
   default machine.

-c stanza=value[:substanza] keyword1=value1... }
   When used with -s, changes the value of a keyword in a stanza or
   substanza to the specified value. When specified with the -s flag, a
   stanza type and stanza name is specified in addition to the
   keyword-value pairs being changed. To change values in a substanza,
   specify the substanza name as well.

-s 
   Specifies that stanza mode is used. The flags that follow it apply to
   administration stanzas and keywords. The -s flag can be used with the
   -a, -c, -d, or -r flag. 

   In stanza mode, the stanza is specified using this format:    

   stanza= value[:substanza]    

   where: 

   *  stanza is one of the LoadLeveler stanza types: 

      *  Class
      *  Cluster
      *  Group
      *  Machine
      *  Machine_group
      *  Region
      *  User

   *  value is the name of a specified stanza instance.

   *  substanza is the name of a specified user or machine substanza
      instance.

-a 
   Adds a new stanza to the configuration without setting values. If the
   stanza already exists in the database, an error message will be
   printed out. This flag is only valid in stanza mode (when using the
   -s flag).

-r 
   Removes the specified stanza from the database. If the stanza does
   not exist in database, an error message will be printed out. This
   flag is only valid in stanza mode (when using the -s flag).



Description


The llrconfig command is used to manage LoadLeveler's configuration
database. You can only specify one -i, -c, or -d flag at a time. In
stanza mode, you can specify only one of the -a, -c, -d, or -r flags
with the -s flag.

To initialize the database configuration of LoadLeveler, llrconfig -i
provides several ways to put the LoadLeveler configuration and
administration information into the database.

The following table lists some of your configuration and database 
information options: 

LoadLeveler configuration and database information options
+-----------------------+----------------------+----------------------+
| Initialize command    | When to use:         | Which files are      |
| option:               |                      | used:                |
+-----------------------+----------------------+----------------------+
| llrconfig -i          | If LoadLeveler is    | The first            |
|                       | already configured   | configuration file   |
|                       | using a file-based   | found by searching   |
|                       | configuration        | in these locations:  |
|                       |                      |  * The configuration |
|                       |                      | file pointed to by   |
|                       |                      | the LoadLConfig      |
|                       |                      | keyword in the       |
|                       |                      | /etc/LoadL.cfg       |
|                       |                      | master configuration |
|                       |                      | file                 |
|                       |                      |  * A default         |
|                       |                      | configuration file,  |
|                       |                      | LoadL_config, found  |
|                       |                      | in the home          |
|                       |                      | directory of the     |
|                       |                      | LoadLeveler user ID  |
|                       |                      |  * The sample        |
|                       |                      | configuration file   |
|                       |                      | LoadL_config.l from  |
|                       |                      | the samples          |
|                       |                      | directory            |
+-----------------------+----------------------+----------------------+
| llrconfig -i -f       | If you want to use   | The specified files  |
| config_file_list      | one or more          | are used, in the     |
|                       | configuration files  | order that they were |
|                       | to load the database | specified.           |
+-----------------------+----------------------+----------------------+
| llrconfig -i -t       | If you have set up a | Any files specified  |
| cluster_configuration | cluster              | by the -f option     |
| _file -f              | configuration file   | followed by the      |
| config_file_list      | for use with xCAT    | LoadLeveler section  |
|                       |                      | of the file          |
|                       |                      | specified by the -t  |
|                       |                      | option.              |
+-----------------------+----------------------+----------------------+

You can use the -f option to list one or more configuration files. If
duplicate keywords are specified in the configuration files, the value
of the last keyword will be used. If a LoadL_config.local file is
specified in the list, the keywords found in that file will be set for
the default or global configuration, rather than for any specific
machine. To specify machine-specific information, you need to set those
keywords in the machine or machine_group stanzas in the administration
file associated with the configuration file used to load the
configuration database, or update the configuration database for
specific machines after the initialize command has run. You cannot
specify an administration file in the list of configuration files.
However, you can supply one administration file to use for initializing
the database by assigning it to the ADMIN_FILE keyword in a
configuration file that is in the list. If ADMIN_FILE is specified in
more than one configuration file, only the last one will be used to
initialize the configuration. The LOCAL_CONFIG keyword is ignored during
database initialization.

When llrconfig -i is run, for any value that the user specifies that is
the same as the LoadLeveler code default value, no value will be set in
the configuration database.

Running llrconfig -i will create some scripts (llserver.sh and
llcompute.sh) in xCAT's postscript directory that can be used to assist
in creating the LoadLeveler /etc/LoadL.cfg file, LOG, SPOOL, and EXECUTE
directories on the nodes. Add these postscripts to the corresponding
xCAT nodegroups' postscript attributes to have them automatically
invoked when provisioning the nodes. For example, add an entry for the
xCAT postscripts table using the xCAT command:

chdef llcompute -p postscripts="llcompute.sh"

If any updates are made to change the LOG, SPOOL, or EXECUTE directory
using llrconfig -c, make sure the
/install/postscripts/LoadL/llr_config_directories file is also updated
to reflect the new directories.

It is suggested you do not run the initialization more than once. If you
run the initialize option again after the database has been initialized,
the database will be populated again from the configuration files and
any updates that were made to configuration parameters will be lost. If
you reinitialize with changes made to the defined machines, machine
groups, or cluster names, unexpected results may be seen when running
llrconfig -s.

The initialize option must be run by the root user. It must be run on a
node where the database or database client is installed.

To update the database after initialization, you can issue the llrconfig
-c command on any LoadLeveler node that has been set up to access the
database using unixODBC. To specify machine-specific information, use
the -h flag to specify one or more machines. Changes made without the -h
flag apply to the default or global machine. To make changes to the
configuration stanzas, for class, cluster, group, machine,
machine_group, region, or user, use llrconfig -s and the -a, -c, or -r
option.

It is not necessary to reconfigure LoadLeveler to pick up changes made
using the llrconfig -c command. A reconfiguration will be propagated to
the nodes needing reconfiguration. If you want to prevent the
reconfiguration when llrconfig is issued, use the -N option.

When several keyword changes are specified on the command line, if the
value of a keyword cannot be changed, an error message will be printed
and the command will continue to change the value of the next keyword.

To remove the setting of a keyword, set it using the format -c keyword=
or -c keyword="". If set without a value, the keyword's value will be
removed. To remove an entire stanza, use llrconfig -s -r stanza.

If keyword="value" is specified with the -c flag, the quotes will not be
part of the assigned value. You must use quotes whenever the value
includes shell special characters. For example, llrconfig -c start = 4 >
5 is not correct and should be written as llrconfig -c start = "4 > 5".
If a LoadLeveler variable is part of the assignment, use single quotes
to prevent resolution by the shell. For example, issue: llrconfig -c log
= '/var/loadl/$(host)'. 

When using the -d option, deprecated keywords are not displayed even if
the keyword was added using the deprecated format. For example, if
central_manager=true was defined in the machine stanza, you should
issue:

llrconfig -d central_manager_list

to display the value because the central_manager keyword in the machine
stanza is deprecated in favor of central_manager_list.


Examples


1. To migrate your existing file-based configuration to the
   configuration database, issue: 

   llrconfig -i

2. To initialize a configuration using a cluster configuration file and
   one of the provided sample files, issue: 
       
   llrconfig -i -t /tmp/cluster_file  -f \ 
   /usr/lpp/LoadL/resmgr/full/samples/LoadL_config.l    

   where: /tmp/cluster_file contains:    

   # LoadLeveler cluster manager daemons and administrator
   ll-config:
        central_manager_list = hmc01 hmc02 hmc03
        resource_mgr_list = hmc01 hmc02 hmc03
        loadl_admin = loadl root loadladmin
        schedd_list = bbxn01 bbxn02 bbyn01 bbyn02

3. To initialize a configuration with keywords from the specified files,
   issue: 

   llrconfig -i -f /usr/lpp/LoadL/resmgr/full/samples/LoadL_config \ 
   /usr/lpp/LoadL/resmgr/full/samples/LoadL_config.local    

   Note: The local file keywords are applied to the global or default
   machine rather than a particular machine.

4. To show the value of the polling_frequency, issue: 

   llrconfig -d polling_frequency

5. To change the configured default polling_frequency to 120, issue: 

   llrconfig -c polling_frequency = 120

6. To set debug flags for the Schedd daemon on c197blade3b01, issue: 

   llrconfig -h c197blade3b01 -c SCHEDD_DEBUG=D_FULLDEBUG

7. To reset debug flags to use the default value for the Schedd daemon
   on c197blade3b01, issue: 

   llrconfig -h c197blade3b01 -c SCHEDD_DEBUG=    

   or    

   llrconfig -h c197blade3b01 -c SCHEDD_DEBUG=""

8. To change class initiators on machine c94n01, issue: 

   llrconfig -h c94n01 -c class="small(4) large(3)" max_starters = 6 

9. To change schedd_debug to "D_ALWAYS D_FULLDEBUG D_SCHEDD", and
   master_debug to "D_ALWAYS D_FULLDEBUG" for machine c94n01, issue: 

   llrconfig -h c94n01 -c schedd_debug = D_ALWAYS D_FULLDEBUG D_SCHEDD \ 
   master_debug = D_ALWAYS D_FULLDEBUG 

10. To make several changes and only run reconfiguration after the last,
   issue:

   llrconfig -N -c max_starters = 3
   llrconfig -N -c class = "small(5) large(1)"
   llrconfig -c resources = "ConsumableCpus(4) licenseA(1)"

11. To display all the class stanzas in the configuration database,
   issue:

   llrconfig -s -d class     

   You should receive a response similar to the following:

   small
   inter_class
   large

12. To display the values set for the class stanza small, issue: 

   llrconfig -s -d class=small

   You should receive a response similar to the following:
   small: type=class
   	 vhu: type = user {
   		maxidle = 6
     }

13. To display the machines defined in the cluster, issue:

   llrconfig -s -d machine

   You should receive a response similar to the following:

   default
   c917f3jp03.ppd.pok.ibm.com
   c917f3jp04.ppd.pok.ibm.com
   c917f3jp05.ppd.pok.ibm.com
   c917f3jp06.ppd.pok.ibm.com
   c917f3jp07.ppd.pok.ibm.com
   c917f3jp08.ppd.pok.ibm.com

14. To display the machine groups defined in the database, issue: 

   llrconfig -s -d machine_group

   You should receive a response similar to the following:

   mg1
   mg2

15. To display the values set for machine group mg1, issue:

   llrconfig -s -d machine_group=mg1

   You should receive a response similar to the following:

   mg1: type=machine_group
     machine_list = c1f1b01,c1f1b02,c1f1b03
     c197blade1b01: type = machine {
       schedd_runs_here = true
     }

16. To display the values set for the user substanza vhu in the class
   stanza small, issue:

   llrconfig -s -d class=small:vhu

17. To add a new group stanza to the database, issue: 

   llrconfig -s -a group=hpc

   Note: The group is added with no attributes.

18. To change the attributes of the class stanza small in the database,
   issue:

   llrconfig -s -c class=small max_queue=10 cpu_limit=30  

19. To add new class stanzas and machine stanzas that are contained in a
   stanza file, create the file containing the stanzas to add. This
   shows the contents of an example file named patch_admin.file:

    #  Add two classes
         interactive:       type = class
                   wall_clock_limit = 20:30,20:00
                   priority = 100
         POE:            type = class
                   wall_clock_limit = 24:00:00,24:00:00
                   priority = 55
         # 4 new nodes using the default attributes
         n12:       type = machine
         n23:       type = machine
         n34:       type = machine
         n45:       type = machine

   Then issue:

   llrconfig -s -a -f  patch_admin.file

20. To remove an existing user stanza "joe" from the database, issue:

   llrconfig -s -r user=joe

21. To change the value of schedd_runs_here for machine i08n008, which
   is part of machine_group mg4, first view the machine group to
   determine if there already is a machine substanza for the machine you
   want to modify in the machine group, by issuing:

   llrconfig -s -d machine_group=mg4    

   If there is no machine substanza, you should receive a response
   similar to the following:

   mg4: {
           type=machine_group
           machine_list=i08n001-i08n008,
           max_starters=32
           island=island1
           class=No_Class(32) interactive(32) large(32)
           resources=ConsumableCpus(all) ConsumableMemory(65536)
   }  


   If there is no substanza for the machine i08n008, add one by issuing:

   llrconfig -s -a machine_group=mg4:i08n008

   This adds an empty machine substanza to the machine_group.
    

   Next, set the value of schedd_runs_here=true for machine i08n008, by
   issuing:

   llrconfig -s -c machine_group=mg4:i08n008 schedd_runs_here=true
    

   Finally, view the change in the machine group by issuing:

   llrconfig -s -d machine_group=mg4

   You should receive a response similar to the following:

   mg4: {
           type=machine_group
           machine_list=i08n001-i08n008,
           max_starters=32
           island=island1
           class=No_Class(32) interactive(32) large(32)
           resources=ConsumableCpus(all) ConsumableMemory(65536)
           i08n008.ppd.pok.ibm.com: {
                   type=machine
                   schedd_runs_here=true 
           }
   }


Results

*  When no errors are found:

   [c197blade8b14][/]> llrconfig -i
   LoadLeveler tables are being created in the xcatdb database.
   Initializing configuration data in the LoadLeveler tables from the 
   following file or files:
   
   /u/loadl/LoadL_config.c197blade8b14
   
   Continue? (y/n): y
   llrconfig: The database initialization has completed. 

*  When information messages or errors are found during configuration
   check, and the configuration database is still initialized: 

   [c197blade8b14][/]> llrconfig -i
   LoadLeveler tables are being created in the xcatdb database.
   Initializing configuration data in the LoadLeveler tables from the
   following file or files:
   /u/loadl/LoadL_config
   Continue? (y/n): y
   negotiator_debug: The value, d_loadl, is not valid.
   starter_debug: The keyword is specified in the configuration but has no 
   value set.
   trunc_gsmonitor_log_on_open: The keyword is no longer supported.
   releasedir: can't read "/opt/ibmll/LoadL/fulla".
   bin: can't read "$(RELEASEDIR)/bin".
   lib: The keyword is no longer supported.
   acct_validation: can't execute "$(BIN)/llacctval".
   kbdd: can't execute "$(BIN)/LoadL_kbdd".
   startd: can't execute "$(BIN)/LoadL_startd".
   process_tracking_extension: can't read "$(BIN)".
   region_mgr: can't execute "$(BIN)/LoadL_region_mgr".
   resource_mgr: can't execute "$(BIN)/LoadL_resource_mgr".
   schedd: can't execute "$(BIN)/LoadL_schedd".
   negotiator: can't execute "$(BIN)/LoadL_negotiator".
   starter: can't execute "$(BIN)/LoadL_starter".
   master: can't execute "$(BIN)/LoadL_master".
   llrconfig: The database initialization has completed.


Security


Only the root user can issue this command with the -i flag on a node
running the database software.

LoadLeveler administrators must login to a node with database access
through unixODBC and have ODBC set up for their IDs providing permission
to issue this command with the -c, -d, -a, or -r flag.