llrctl - Control LoadLeveler daemons

Use the llrctl command to control LoadLeveler daemons on all members of
the LoadLeveler cluster.


Syntax


llrctl { -? | -H | -v | [-q] [-g | -h host] keyword }


Flags


-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-q 
   Specifies quiet mode: print no messages other than error messages.

-g 
   Indicates that the command applies globally to all machines, except
   submit-only machines, that are listed in the administration file.

-h host
   Indicates that the command applies to only the host machine in the
   LoadLeveler cluster. If -h is not specified, the default is the
   machine on which the llrctl command is issued.

keyword
   Must be specified after all flags and can be the following: 

   capture eventname
      Captures accounting data for all jobs running on the designated
      machines. eventname is a user-defined name associated with the
      data when you run this command. It must be a character string
      containing no blanks. The data is captured in the accounting
      records in the history file. For more information, see the
      discussion of collecting job resource data based on events in 
      LoadLeveler: Using and Administering.

   ckconfig
      Checks the defined configuration. ckconfig reads either the
      configuration database or the configuration files (including the
      global, local, and the administration files), and reports all
      error and informational messages. The errors and informational
      messages produced by ckconfig will be sent to standard error and
      will also be logged to the ckconfigLog file located in the
      directory specified in $LOG in the configuration file.

   drain [schedd | startd [classlist | allclasses]]
      
      *  When you issue drain with no options, the following occurs:
 
         1. No more LoadLeveler jobs can begin running on this machine.

         2. No more LoadLeveler jobs can be submitted through this
            machine.

      *  When you issue drain schedd, the following occurs: 

         1. The Schedd machine accepts no more LoadLeveler jobs for
            submission.

         2. Job steps in the Starting or Running state in the Schedd
            queue are allowed to continue running.

         3. Job steps in the Idle state in the Schedd queue are drained,
            that is, they will not get dispatched.

      *  When you issue drain startd, the following occurs: 

         1. The startd machine accepts no more LoadLeveler jobs to be
            run.

         2. Job steps already running on the startd machine are allowed
            to complete.

      *  When you issue drain startd classlist, the classes you specify
         that are available on the startd machine are drained (made
         unavailable).

      *  When you issue drain startd allclasses, all available classes
         on the startd machine are drained.

   dumplogs [buffer | locks | flush]
      When the logging buffer or lock recording is enabled, llrctl
      dumplogs will cause the log messages in the logging buffer or
      locking records to be written to the related log file. 

      where: 

      buffer
         Dumps out logs in the circular logging buffer. This is the
         default type. For more information, see the topic, 
         "Controlling the logging buffer" in LoadLeveler: Resource 
         Manager.

      locks
         Dumps out locking records. For more information, see the 
         topic, "Controlling locking records" in LoadLeveler: Resource 
         Manager.

      flush
         Terminates running jobs on this machine and sends them back, in
         the Idle state, to the negotiator to await redispatch (provided
         restart=yes is in the job command file). No new jobs are sent
         to this machine until resume is issued. This keyword forces a
         checkpoint if jobs are enabled for checkpointing. However, the
         checkpoint is canceled if it does not complete within the time
         period specified in the ckpt_time_limit keyword in the job
         command file.

   reconfig
      Forces all daemons to reread the administration and configuration
      files.

   recycle
      Stops all LoadLeveler daemons and restarts them.

   resume [schedd | startd [classlist | allclasses]]
      
      *  When you issue resume schedd, the following occurs: 

         1. The Schedd machine accepts LoadLeveler jobs for submission.

         2. Job steps in the Idle state in the Schedd queue are resumed,
            that is, they will be considered for dispatch.

      *  When you issue resume startd, the startd machine accepts
         LoadLeveler jobs to be run.

      *  When you issue resume with no options, the actions described
         for both resume schedd and resume startd are taken.

      *  When you issue resume startd classlist, the startd machine
         resumes the execution of those job classes you specify that are
         also configured (defined on the machine).

      *  When you issue resume startd allclasses, the startd machine
         resumes the execution of all configured classes.

   rmshm
      Allows root to remove all LoadLeveler shared memory segments and
      associated semaphores.

   start [drained]
      
      *  When you issue start with no options, it starts the LoadLeveler
         daemons on the machine or machines designated, either
         explicitly or implicitly.

      *  When you issue start without the -g or -h flag, the LoadLeveler
         daemons are started on the same machine that issued the
         command.

      *  When you issue llrctl start with either the -g or -h flag, the
         command specified by the LL_RSH_COMMAND configuration file
         keyword is used to run the command on all machines specified in
         the administration file. If LL_RSH_COMMAND is not specified,
         remote shell (rsh) is used and you must have rsh privileges in
         order to use llrctl start with either the -g or -h flag.

      *  When you issue start with the drained option, the LoadLeveler
         daemons are started, but the startd daemon is started in the
         drained state.

   stop
      Stops the LoadLeveler daemons on the specified machine.

   suspend
      Suspends all jobs on this machine. This is not supported for
      parallel jobs.

   version
      Displays release number, service level, service level date, and
      operating system information for every LoadLeveler executable. 

      When you issue llrctl start or llrctl version with either the -g
      or -h flag, the command specified by the LL_RSH_COMMAND
      configuration file keyword is used to run the command on all
      machines specified in the administration file. If LL_RSH_COMMAND
      is not specified, remote shell (rsh) is used and you must have rsh
      privileges in order to use llrctl start or llrctl version with
      either the -g or -h flag.       

      LoadLeveler commands that run rsh include llrctl version and
      llrctl start.


Description


This command sends a message to the master daemon on the target machine
requesting that action be taken on the members of the LoadLeveler
cluster. Note the following when using this command: 

*  To perform the control operations of the llrctl command, you must be
   a LoadLeveler administrator. The only exceptions to this rule are the
   start and rmshm operations.

*  LoadLeveler will fail to start if any value has been set for the
   MALLOCTYPE environment variable.

*  For a file-based configuration, after you make changes to the
   administration and configuration files for a running cluster, be sure
   to issue llrctl reconfig. This command causes the LoadLeveler daemons
   to reread these files, and prevents problems that can occur when the
   LoadLeveler commands are using a new configuration while the daemons
   are using an old configuration. 

   For the database configuration option, you should reconfigure after
   you update the configuration database using the configuration editor.

   Note: Changes to SCHEDULER_TYPE will not take effect at
   reconfiguration. The administrator must stop and restart or recycle
   LoadLeveler when changing SCHEDULER_TYPE.

*  The llrctl drain startd classlist command drains classes on the
   startd machine, and the startd daemon remains operational. If you
   reconfigure the daemon, the draining of classes remains in effect.
   However, if the startd machine goes down and is brought up again
   (either by the master daemon or by a LoadLeveler administrator), the
   startd daemon is configured according to the global or local
   configuration file in effect, and therefore the draining of classes
   is lost. 

   Draining all the classes on a startd machine is not equivalent to
   draining the startd machine. When you drain all the classes, the
   startd enters the Idle state. When you drain the startd, the startd
   enters the Drained state. Similarly, resuming all the classes on a
   startd machine is not equivalent to resuming the startd machine.

*  If a job step is running on a machine that receives the llrctl
   recycle command, or the llrctl stop and llrctl start commands, the
   running job step is terminated. If the restart option in the job
   command file was set to yes, then the job step will be restarted when
   LoadLeveler is restarted. If the job step is checkpointable, it will
   be restarted from the last valid checkpoint file when LoadLeveler is
   restarted.

*  If you find that the llrctl -g command (even if it is specified with
   additional options) is taking a long time to complete, you should
   consider using the xCAT command xdsh to send llrctl commands
   (omitting the -g flag) to multiple nodes in a parallel fashion.


Examples

1. This example stops LoadLeveler on the machine named iron: 

   llrctl -h iron stop

2. This example starts the LoadLeveler daemons on all members of the
   LoadLeveler cluster (with the exception of the submit-only machines),
   starting with the central manager, as defined in the machine stanzas
   of the administration file: 

   llrctl -g start

3. This example causes the LoadLeveler daemons on machine iron to
   re-read the administration and configuration files, which may contain
   new configuration information for the iron machine: 

   llrctl -h iron reconfig

4. This example drains the classes medium and large on the machine named
   iron: 

   llrctl -h iron drain startd medium large

5. This example drains the classes medium and large on all machines: 

   llrctl -g drain startd medium large

6. This example stops all the jobs on the system, then allows only jobs
   of a certain class (medium) to run:

   llrctl -g drain startd allclasses
   llrctl -g flush
   llrctl -g resume
   llrctl -g resume startd medium

7. This example resumes the classes medium and large on the machine
   named iron:

   llrctl -h iron resume startd medium large

8. This example illustrates how to capture accounting information on a
   work shift called day on the machine iron: 

   llrctl -h iron capture day   

   You can capture accounting information on all the machines in the
   LoadLeveler cluster by using the -g option, or you can collect
   accounting information on the local machine by simply issuing the
   following: 

   llrctl capture day    

   Capturing information on the local machine is the default. For more
   information, see the "Collecting job resource data based on events"
   topic in  LoadLeveler: Using and Administering.

9. This example saves the locking records for LoadLeveler daemons
   configured with the D_LOCK_TRACE debug flag to the daemon's
   corresponding existing log files in the LOG directory of node
   c197blade7b02:

   llrctl -h c197blade7b02 dumplogs locks


Security


LoadLeveler administrators can issue this command.

Only the root user can issue this command with the rmshm keyword.