llrstatus - Query machine information

Use the llrstatus command to return status information about machines in
the LoadLeveler cluster.


Syntax
 

llrstatus
         [-?] [-H] [-v] [-W] [-R] [-M] [-l] [-a] [-d] [-e]
         [-f category_list] [-r category_list]
         [-L {cluster | machine_group | machine}]
         [-h hostlist | hostlist]


Flags


-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-W 
   Specifies that the width of columns in tabular output will be
   increased to fit the widest entry.

-R 
   Lists the machine consumable resources associated with each machine
   for which status is requested. This option should not be used with
   any other option.

-M 
   Lists the Multiple Chip Modules (MCMs) available on a machine, where:
   

   Available CPUs
            Are the CPU IDs of the CPUs available for LoadLeveler on
            this MCM.
   Adapters Are the switch adapters connected to this MCM of the form: 
            [available windows, available rCxtBlocks]             

            where:             

            available windows
                     Is the total number of windows on the adapter.

            available rCxt blocks
                     Is the total number of rCxt blocks on the adapter.
    

   Note that the < > notation will be used to list individual CPU IDs
   instead of the CPU count ( ) notation when the RSET_SUPPORT
   configuration file keyword is set to RSET_MCM_AFFINITY.

-l 
   Specifies that a long listing be generated for each machine for which
   status is requested. If -l is not specified, the standard list is
   generated.

-a 
   Displays information for each virtual adapter followed by information
   for each physical adapter it manages. This flag also displays the
   port number on each InfiniBand adapter port.

-d 
   Displays a list of regions and its corresponding active region
   manager.

-e 
   Displays the energy coefficients information.

-f category_list
   Is a blank-delimited list of categories you want to query. Each
   specified category must be preceded by a percent sign. The
   category_list cannot contain duplicate entries. This flag is used to
   create a customized version of the standard llrstatus listing. The
   output fields produced by this flag all have a fixed length. The
   output is displayed in the order in which the categories are
   specified. category_list can be one or more of the following: 

   %a       Hardware architecture

   %act     Number of job steps dispatched by the resource manager
            daemon on this machine

   %cm      Custom Metric value

   %cpu     Number of CPUs on this machine

   %d       Available disk space in the LoadLeveler execute directory

   %i       Number of seconds since last keyboard or mouse activity

   %inq     Number of job steps in the job queue of this job manager
            machine

   %l       Berkeley one-minute load average

   %m       Physical memory on this machine

   %n       Machine name

   %o       Operating system on this machine

   %sca     Availability of the job manager daemon

   %scs     State of the job manager daemon

   %sta     Availability of the startd daemon

   %sts     State of the startd daemon

   %v       Available swap space (free paging space) of this machine

-r category_list
   Is a blank-delimited list of categories to query. Each specified
   category must be preceded by a percent sign. The category_list cannot
   contain duplicate entries. This flag is used to create a customized
   version of the standard llrstatus listing. The output produced by
   this flag is considered raw, in that the fields can be variable in
   length. Output fields are separated by an exclamation point (!).
   category_list can be one or more of the categories listed under the
   -f flag.

-L {cluster | machine_group | machine}
   Selects the level of detail to be displayed, where: 

   cluster
      Displays a brief, high-level summary of the state of the machines
      in the cluster. When combined with the -l option, the listing is
      expanded to show which machines are currently in an unavailable
      state. For machines configured to run Startd, available is defined
      as Idle, Running, or Busy, and unavailable is defined as Down,
      Draining, Drained, Flush or Suspended. For machines configured to
      run Schedd, available is defined as Avail and unavailable is
      defined as Down or Drained.

   machine_group
      Displays information on a machine group basis. The standard
      listing displays one line for each machine group containing a
      high-level summary of the state of the machines within that group.
      When the -l option is used, a long listing is displayed, showing a
      list of the machines belonging to the group along with detailed
      configuration and status information.

   machine
      Displays information on a machine basis. The standard listing
      displays one line for each machine. When the -l option is used, a
      long listing is displayed.

-h hostlist
hostlist
   Is a blank-delimited list of machines and machine groups for which
   status is requested. 

   Note: If a configuration has a machine group and a machine sharing
   the same name, the llrstatus command will always assume that the name
   refers to the machine group.    

   If the -X flag is specified in combination with a hostlist, the -h
   flag must be specified. For example: 

   llrstatus -X my_cluster1 my_cluster2 -h c94n13 c94n14


Description


If you have more than a few machines configured for LoadLeveler,
consider redirecting the output to a file when using the -l  flag. Each
machine periodically updates the resource manager with a snapshot of its
situation on an interval calculated by POLLING_FREQUENCY *
POLLS_PER_UPDATE. Since the information returned by using llrstatus is a
collection of such snapshots, all taken at varying times, the total
picture may not be completely consistent.

Certain resources such as remote direct-memory access (RDMA) have their
available value always calculated by startd. Available ConsumableCpus
resources are calculated by startd if the value is specified as all in
the administration file. When the value of a resource is calculated by
startd, the llrstatus command appends a plus (+) sign to the resource
name in the output reports. Resources that are automatically created,
such as RDMA, have a less than (<) sign appended to them.

Notes on using the -L option: 

1. The -L option only applies to the standard listing (no other option
   specified) and the long listing (-l).

2. The -f and  -r options are only supported with -L machine. Using
   these options with -L cluster or -L machine_group will result in an
   error.

3. The -L option cannot be used in combination with -a, -e, -M, or -R,
   or an error will result.

Notes on using the hostlist option: 

1. For a machine-level option (-L machine or any existing llrstatus
   options such as -a, -M, or -R), a machine group in the hostlist will
   expand to include all of the machines defined in that machine group.

2. For the machine_group-level option (-L machine_group), the hostlist
   will be used to select which machine groups will be displayed.
   Specifying a machine group name in the hostlist will result in that
   machine group being displayed. Specifying a machine name in the host
   list will result in the machine group to which that machine belongs
   being displayed. If a machine name is specified, and that machine
   does not belong to a machine group, then the row OTHERS will be
   displayed. The OTHERS row contains a collection of those machines
   that are not defined as part of a machine group, and in the case
   where a hostlist is specified, only the requested machines are
   included.

3. For the cluster-level option (-L cluster), the hostlist is ignored.

Default behavior of the llrstatus command

The default output of the llrstatus command can be changed using the
LOADL_STATUS_LEVEL environment variable. Its value can be one of the
following: 

CLUSTER
   When LOADL_STATUS_LEVEL=CLUSTER, specifying the llrstatus command
   without the -L option is equivalent to specifying llrstatus -L
   cluster. Cluster level output is the default for the llrstatus
   command.

MACHINE_GROUP
   When LOADL_STATUS_LEVEL=MACHINE_GROUP, specifying the llrstatus
   command without the -L option is equivalent to specifying llrstatus
   -L machine_group.

MACHINE
   When LOADL_STATUS_LEVEL=MACHINE, specifying the llrstatus command
   without the -L option is equivalent to specifying llrstatus -L
   machine.

Notes: 
1. If the LOADL_STATUS_LEVEL  environment variable is not set to
   CLUSTER, MACHINE_GROUP, or MACHINE, the llrstatus command will
   display the cluster level information by default.

2. The llrstatus command with the -R, -M, -a, or -e options will ignore
   the value set for the LOADL_STATUS_LEVEL environment variable.


Examples


1. This example generates the cluster-level standard listing. The
   standard listing is generated when you do not specify the -l option
   with the llrstatus command. Alternatively, set the environment
   variable LOADL_STATUS_LEVEL=cluster and issue:

   llrstatus   

   Or, issue:    

   llrstatus -L cluster     

   You should receive output similar to the following: 

   Active            1/2
   Schedd            1/1                  0 job steps
   Startd            1/2                  0 running tasks
   RegionMgr         1/1
   
   Total Computing nodes in Standby (S3) state    0 machines
   
   The Resource Manager is defined on c596n11.ppd.pok.ibm.com
   
   
   Absent:            1
   Startd:         Down    Suspend
                      0          0
   Schedd:         Down    Drained   Draining
                      0          0          0
   RegionMgr:      Down  Alternate
                      0          0

   Active     16210/16300
   Schedd         95/96    2487 job steps
   Startd     16196/16200 517832 running tasks
   RegionMgr    128/128
   The Resource Manager is defined on percscm1.clusters.com
   
   Absent:     90
   Startd:    Down  Drained   Draining 	 Flush 	Suspend
                 1        0        0        0         3
   Schedd:    Down  Drained   Draining
                 1        0          0
   RegionMgr: Down   Alternate
                 1        1

   This output indicates that there is 1 startd down, no startd drained,
   no startd draining, no startd flush, 3 startds suspend, no Schedd
   drained, no Schedd draining, 1 Schedd down and 90 machines absent.
   The last four lines show a brief summary, which indicates there are
   totally 16,300 machines defined in the administration file or
   database, and 16,210 machines have reported their status to the
   Resource Manager daemon. Out of 96 machines known by the Central
   Manager to be Schedd machines, 95 are up and able to accept jobs.
   Among these Schedd machines there 2,487 queued job steps in various
   states. Out of 16,200 machines known to be Startd machines, 16,196
   are up and either already running jobs or able to run jobs. Among
   these 16,196 Startd machines there are a total of 517,832 running
   tasks belonging to various jobs. And finally, the Central Manager is
   identified.
    

   Note: The totals for RegionMgr indicate the number of Region Managers
   serving out of the total number of regions defined. This count may
   include alternate Region Managers, which have taken over after a
   primary Region Manager has become unavailable. This is broken out
   below, where "Down" is a count of the primary Region Managers which
   are down and "Alternate" is a count of the alternate Region Managers
   serving. If these two numbers are equal, then all regions are being
   served, but if Down is greater than alternate, then some regions are
   currently without a Region Manager.

2. This example shows machine_group status for the cluster.

   llrstatus -L machine_group    

   Or alternatively, set the environment variable
   LOADL_STATUS_LEVEL=machine_group and issue:

   llrstatus    

   You should receive output similar to the following:

   GROUP_NAME   Schedd InQ    Act   Startd      Run Nmachs 
   x330          8/8    90     11   99/100     1936 100    
   pccluster    20/21   88     12  597/600    97227 600    
   cnblade       9/9    21     21 9998/10000  10416 10000  
   c197blade    46/46  769    159 5495/5498   13252 5498   
   OTHERS        2/2     1      1    2/2          1 2

    
   Note: The OTHERS row contains a collection of machines that are not
   defined as part of any machine group.

3. This example shows that for machine level, llrstatus will print all
   the machines.

   llrstatus -L machine    

   Or alternatively, set the environment variable
   LOADL_STATUS_LEVEL=machine and issue:

   llrstatus    

   You should receive output similar to the following:

   Name                    Schedd InQ Act Startd Run LdAvg Idle Arch  OpSys
   k10n09.ppd.pok.ibm.com  Avail   3   1  Run      1 2.72     0 R6000 AIX71
   k10n12.ppd.pok.ibm.com  Avail   0   0  Idle     0 0.00   365 R6000 AIX71
   
   R6000/AIX71            2 machines   3 jobs   1 running tasks
   Total Machines         2 machines   3 jobs   1 running tasks
    
   The Resource Manager is defined on k10n09.ppd.pok.ibm.com
   
   All machines on the machine_list are present.     

   The standard listing includes the following fields: 

   Act      The number of job steps dispatched by the Schedd daemon on
            this machine.

   Arch     The hardware architecture of the machine as listed in the
            configuration file.

   Idle     The number of seconds since keyboard or mouse activity in a
            login session was detected. Highest number displayed is
            9999.

   InQ      Number of job steps in the job queue of this Schedd machine.

   LdAvg    Berkeley one-minute load average on this machine.

   Name     Host name of the machine.

   OpSys    The operating system on this machine.

   Run      The number of initiators used by the startd daemon to run
            LoadLeveler jobs on this machine. One initiator is used for
            each serial job step and one initiator is used for each task
            of a parallel job step.

   Schedd   State of the Schedd daemon, which can be one of the
            following: 

            *  Down
            *  Drned (Drained)
            *  Drning (Draining)
            *  Avail (Available)             

            For more information, see "The Schedd daemon" topic in 
            LoadLeveler: Resource Manager.


   Startd   State of the startd daemon, which can be: 
            *  Busy
            *  Down
            *  Drned (Drained)
            *  Drning (Draining)
            *  Flush
            *  Idle
            *  None
            *  Run (Running)
            *  Suspnd (Suspend)
             

            For more information, see "The startd daemon" topic in 
            LoadLeveler: Resource Manager.

   Total Machines
            The standard listing includes the following summary fields: 

            jobs     The number of job steps in LoadLeveler job queues.

            machines The number of machines in the cluster that have
                     made a status report to the central manager.

            running tasks
                     The number of initiators used by all the startd
                     daemons in the LoadLeveler cluster. One initiator
                     is used for each serial job step. One initiator is
                     used for each task of a parallel job step.    

   The standard listing also contains summary information for the
   cluster such as the type of scheduler and the cluster name.

4. This example generates the long listing. The long listing is
   generated when you specify the -l flag with the llrstatus -L machine
   command. See Appendix C, "llrstatus -l command output listing" for
   sample output of long listings. 

   llrstatus -L machine -l c271f2rp02    

   Alternatively, set the environment variable
   LOADL_STATUS_LEVEL=machine and issue: 

   llrstatus -l c271f2rp02    

   The long listing includes the following fields: 

   Adapter  Network adapter information associated with this machine. 

            *  For a switch adapter, the information format is: 

               adapter_name(network_type, interface_name, interface_address,
               multilink_address, switch_node_number or adapter_logical_id,
               total_adapter_windows, total rCxt blocks, total imm send buffers,
               adapter_fabric_connectivity)                

               For example:                

               Adapter = network1833865768265265971s(striped,ml0,10.0.0.53,,-1,0,
                  0 rCxt Blks,0111,) 
               network18338657682652659713(aggregate ,,,10.0.0.53,-1,0,
                  0 rCxt Blks,0,) 
               network18338657682652659714(aggregate,,,10.0.0.53,-1,64,
                  0 rCxt Blks,1,) 
               network18338657682652659715(aggregate,,,10.0.0.53,-1,64,
                  0 rCxt Blks,1,) 
               network18338657682652659716(aggregate,,,10.0.0.53,-1,64,
                  0 rCxt Blks,1,)                 

               Possible values for adapter_state are:                

               AdapterHBInterval
                        Specifies the amount of time, in seconds, that
                        defines the heartbeat interval between the
                        region manager and startd.

               AdapterHBRetries
                        Specifies the number of heartbeat intervals that
                        the region manager will wait before declaring
                        the adapter on startd as down.

               ErrAdapter 
                        The adapter information is incorrect. More
                        information might be available in the network
                        table API log.

               ErrDown  The adapter has been reported as down. This
                        field is displayed as part of the command output
                        when the adapter is found to be down by either
                        an adapter heartbeat, or by the input/output
                        control (ioctl) or protocol network services
                        daemon (PNSD) status on the machine.

               ErrInternal
                        An error occurred while accessing the adapter.
                        More information might be available in the
                        network table API log and if the D_FULLDEBUG and
                        D_ADAPTER flags are specified for STARTD_DEBUG.

               ErrNotConfigured
                        The adapter is not configured. This field is
                        displayed as part of the command output only
                        during start up and reconfiguration as a default
                        value until it is changed by either an ioctl or
                        PNSD, or an adapter heartbeat.

               ErrNTBL  An error occurred while accessing the network
                        table API. More information might be available
                        if the D_FULLDEBUG and D_ADAPTER flags are
                        specified for  STARTD_DEBUG.

               ErrPerm  The network table API reported that LoadLeveler
                        does not have permission to access the adapter.
                        More information might be available in the
                        network table API log.

               ErrPNSD  An error occurred in the network table API. More
                        information might be available in the network
                        table API log.

               ErrType  The network table API reported that the adapter
                        is not a switch adapter. Check the adapter
                        configuration.

               HB_DOWN  Heartbeat is down between the startd and region
                        manager.

               HB_REGION_DOWN
                        The region manager is down.

               HB_UNKNOWN
                        The initial heartbeat state.

               HB_UP    Heartbeat is up between the startd and region
                        manager.

               MachineDown
                        The machine to which the adapter is attached
                        could not be reached by LoadLeveler to query
                        status.

               NOT READY
                        An unspecified problem occurred when accessing
                        the adapter state. More information might be
                        available if the D_FULLDEBUG and D_ADAPTER flags
                        are specified for  STARTD_DEBUG.

               READY    The adapter can be used for communication.

            *  For non-switch adapters, the format is: 

               adapter_name(network_type, interface_name, interface_address,
               interface_netmask, multilink_address, config_state, heartbeat_state, 
               adapter_state)                

               For example:                

               en0(ethernet,c890f4ec05.ppd.pok.ibm.com,9.114.80.53,,READY,HB_UP,
                  READY) 
               ml0(multilink,10.0.0.53,10.0.0.53,,READY,HB_UP,READY)                

               Arch     The hardware architecture of this machine.

               Completed
                        The job manager has this number of completed
                        jobs.

               Config Time Stamp
                        Date and time of last configuration or
                        reconfiguration.

               ConfiguredClasses
                        A list of configured classes and the associated
                        number of configured initiators on this machine.

               ConsumableResources
                        A list of consumable resources associated with
                        this machine. Each element of this list has the
                        format: resource_name(available, total). 

                        Note: The individual CPU ID < > notation will be
                        used to list individual CPU IDs instead of the
                        CPU count ( ) notation for machines where the
                        RSET_SUPPORT configuration file keyword is set
                        to RSET_MCM_AFFINITY. The CPU count ( ) notation
                        will be used when the RSET_SUPPORT configuration
                        file keyword is set to RSET_USER_DEFINED or
                        RSET_NONE, or if this keyword is not specified
                        in the configuration file.

               CONTINUE The expression, defined following C conventions
                        in the configuration file, that evaluates to
                        true or false (T or F). This determines whether
                        suspended jobs are continued on this machine.

               Cpus     The number of CPUs on this machine.

               Current Frequency
                        The current power frequency on this machine.

               Disk     The available space, in kilobytes (less 512 KB)
                        in LoadLeveler's execute directory on this
                        machine.

               Entered Current State
                        The date and time when machine state was set.

               FabricConnectivity
                        Represents the current state of connectivity
                        between the machine and the switch through
                        switch adapters. The format of the field is:
                        network_id: connectivity, network_id:
                        connectivity... where connectivity is either 1
                        or 0. A value of 1 indicates an active
                        connection from the machine to a given
                        network_id through one of the switch adapters. 

                        If a machine does not have switch adapters, the
                        FabricConnectivity field has no meaning and
                        should be ignored by the user.

               Feature  The set of all features on this machine.

               FreeLargePageMemory
                        Free Large Page memory. 

                        In LoadLeveler for Linux, the
                        FreeLargePageMemory field has no meaning and
                        should be ignored by the user.

               FreeRealMemory
                        Free real memory, in megabytes, on this machine.
                        This value should track closely with the "fre"
                        value of the vmstat command and the "free" value
                        of the svmon -G command whose units are 4 KB
                        blocks.

               Held     The job manager has this number of held jobs.

               Idle     The job manager has this number of idle jobs.

               Island   The name of the island to which this machine
                        belongs.

               Keyboard Idle
                        The number of seconds since last keyboard or
                        mouse activity.

               KILL     The expression, defined following C conventions
                        in the configuration file, that evaluates to
                        true or false (T or F). This determines whether
                        jobs running on this machine should be sent the
                        SIGKILL signal.

               LargePageMemory
                        Configured Large Page physical memory. 

                        In LoadLeveler for Linux, the LargePageMemory
                        field has no meaning and should be ignored by
                        the user.

               LargePageSize
                        The size of a Large Page memory block. 

                        In LoadLeveler for Linux, the LargePageSize
                        field has no meaning and should be ignored by
                        the user.

               LoadAvg  The Berkely one-minute load average on machine.

               Machine  The fully qualified name of the machine.

               Machine Mode
                        The type of job this machine can run. This can
                        be: batch, interactive, or general.

               MasterMachPriority
                        The machine priority for the parallel master
                        node.

               Mcms     The MCMs information associated with this
                        machine has the format: 

                        mcm_info ... mcm_info                         

                        The format of mcm_info is:                         

                        MCMnumber Available Cpus: < cpulist > (Total Cpus)  
                        Adapters: adapter_info .... adapter_info                          

                        where:                         

                        Available Cpus
                           Are the CPUs available for LoadLeveler on
                           this MCM.

                        Adapters Are the switch adapters connected to
                           this MCM. 

                           where:                            

                           number   Is the MCM sequence number:

                           cpulist   Is a blank-delimited list of
                           individual CPU IDs or CPU ranges, or a
                           combination of both CPU IDs and CPU ranges
                           associated with the MCM.

                           adapter_info
                           Has the format:

                           [available windows, available memory]                            

                           where:                            

                           available windows
                           Is the total number of available windows.

                           available memory
                           Is the total available memory. It is the
                           number of rCxt blocks for switch adapters.

               Memory   Is the regular physical memory, in megabytes, on
                        this machine.

               Name     Is the host name of the machine.

               OpSys    Is the operating system on this machine.

               PagesFreed
                        Pages freed per second. This value corresponds
                        to the "fr" value of the vmstat command output. 

                        In LoadLeveler for Linux, the PagesFreed field
                        has no meaning and should be ignored by the
                        user.

               PagesPagedIn
                        Pages paged in from paging space per second.
                        This value corresponds to the "pi" value of the
                        vmstat command output. 

                        In LoadLeveler for Linux, the PagesPagedIn field
                        has no meaning and should be ignored by the
                        user.

               PagesPagedOut
                        Pages paged out to paging space per second. This
                        value corresponds to the "po" value of the
                        vmstat command output. 

                        In LoadLeveler for Linux, the PagesPagedOut
                        field has no meaning and should be ignored by
                        the user.

               PagesScanned
                        Pages scanned by the page-replacement algorithm
                        per second. This value corresponds to the "sr"
                        value of the vmstat command output. 

                        In LoadLeveler for Linux, the PagesScanned field
                        has no meaning and should be ignored by the
                        user.

               Pending  The job manager has this number of pending jobs.

               Pool     The identifiers of the pools to which the startd
                        machines of this machine group belong.

               Power Policy
                        The site level energy policy. The crontab entry
                        and duration will be displayed.

               Power State
                        The current machine power state. 

                        where:                         

                        Working  Is when the node is working normally.

                        Standby  Is when the node is suspended.

                        Error    Is when the node failed to suspend or
                                 resume.

                        Pending  Is when the node is transforming
                                 between Working and Standby.

                        Poweroff The node is powered off.

                        Unknown  Is when the S3 function is disabled on
                                 the node.

               Region   Specifies the name of the region to which this
                        machine belongs.

               Remove Pending
                        The job manager has this number of pending jobs
                        to be removed.

               RSetSupportType
                        Indicates the type of RSet support set up on a
                        machine. Possible values are: 

                        RSET_MCM_AFFINITY
                           Creates and attaches RSets for tasks to
                           satisfy memory and affinity requests.
                        RSET_NONE
                           Indicates that LoadLeveler RSet support is
                           not available.
                        RSET_USER_DEFINED
                           Attaches user-created RSets to Tasks.

               Running steps
                        The list of job steps currently running on this
                        machine.

               ScheddAvail
                        The flag indicating if the machine is running a
                        job manager daemon (LoadL_schedd), (0=no,
                        1=yes).

               ScheddRunning
                        The number of job steps submitted to this
                        machine that are running somewhere in the
                        LoadLeveler cluster.

               ScheddState
                        The state of the Schedd daemon on this machine,
                        which can be one of the following:  

                        *  Down
                        *  Drned (Drained)
                        *  Drning (Draining)
                        *  Avail (Available)

               Speed    The speed associated with the machine.

               SMT      Indicates whether the simultaneous
                        multithreading (SMT) function is turned on, off,
                        or is not supported in the running machine.
                        Valid values are Enabled, Disabled, or Not
                        Supported.

               START    The expression, defined following C conventions
                        in the configuration file, that evaluates to
                        true or false (T or F). This determines whether
                        jobs can be started on this machine.

               StartdAvail
                        The flag indicating if machine is running a
                        startd daemon (0=no, 1=yes).

               Starting The job manager has this number of jobs
                        starting.

               State    State of the startd daemon, which can be: 

                        *  Busy
                        *  Down
                        *  Idle
                        *  None
                        *  Running
                        *  Suspend                         

                        For more information, see "The startd
                        daemon" topic in LoadLeveler: Resource Manager.


               Subnet   The TCP/IP subnet that this machine resides on.

               Supported Freq. List
                        The supported power frequencies on this machine.

               SUSPEND  The expression, defined following C conventions
                        in the configuration file, that evaluates to
                        true or false (T or F). This determines whether
                        running jobs should be suspended on this
                        machine.

               TimeStamp
                        The date and time the resource manager last
                        received a status update from the job manager on
                        this machine.

               Tmp      Available space, in kilobytes (less than 512 KB)
                        in the /tmp directory on this machine.

               Total Jobs
                        The number of total job steps submitted to the
                        job manager on this machine.

               TotalMemory
                        The sum of configured regular and Large Page
                        memory.

               Unexpanded
                        The job manager has this number of unexpanded
                        jobs.

               VACATE   The expression, defined following C conventions
                        in the configuration file, that evaluates to
                        true or false (T or F). This determines whether
                        suspended jobs are vacated on this machine.

               Virtual Memory
                        Available swap space (free paging space) in
                        kilobytes, on this machine.

5. This example generates the machine group level long listing. The long
   listing is generated when you specify the -l flag with the llrstatus
   -L machine_group command. See the "llrstatus -l command
   output listing" topic in LoadLeveler: Resource Manager for sample 
   output of long listings. 

   llrstatus -L machine_group -l     

   Alternatively, set the environment variable
   LOADL_STATUS_LEVEL=machine_group  and issue: 

   llrstatus -l     

   The long listing includes the following fields: 

   Completed
            The number of job steps in this state on all the Schedd
            machines of this machine group.

   ConfiguredClasses
            The list of configured classes and the associated number of
            configured initiators on each machine of this machine group.

   ConsumableResources
            The list of consumable resources associated with each
            machine of this machine group. Each element of this list has
            the format: resource_name(available, total). 

            Note: The individual CPU ID < > notation will be used to
            list individual CPU IDs instead of the CPU count ( )
            notation for machines where the RSET_SUPPORT configuration
            file keyword is set to RSET_MCM_AFFINITY. The CPU count ( )
            notation will be used when the RSET_SUPPORT configuration
            file keyword is set to RSET_USER_DEFINED or RSET_NONE, or if
            this keyword is not specified in the configuration file.


   Explicitly Defined
            All the explicitly defined submachines within this machine
            group.

   Feature  The set of all features on each machine of this machine
            group.

   Held     The number the number of job steps in this state on all the
            Schedd machines of this machine group.

   Idle     The number of job steps in this state on all the Schedd
            machines of this machine group.

   Island   The name of the island to which each machine in this machine
            group belongs.

   Machine List
            The machine_list keyword defined in the administration file
            followed by the machines in substanzas. It is possible that
            a machine in a substanza is also included in the
            machine_list keyword.

   Machine Mode
            The type of job each machine of this machine group can run.
            This can be: batch, interactive, or general.

   Max_Dstg_Starters
            A machine-specific limit on the number of data staging
            initiators. This is also the number of initiators available
            on that machine for the data_stage class.

   Max_Starters
            The maximum number of initiators that can be used
            simultaneously on each machine of this machine group.

   Name     The name of the machine group stanza.

   Number of Machines
            Displays the number of machines in this machine group.

   Pending  The number of job steps in this state on Schedd machines of
            this machine group.

   Pool     The identifier of the pool where the startd machines of this
            machine group are located.

   Prestarted_Starters
            The maximum number of Prestarted Starters that can be
            started on this machine or machine group at any time.

   Region   Specifies the name of the region to which this machine group
            belongs.

   Removed  The number of job steps in this state on Schedd machines of
            this machine group.

   Remove Pending
            The number of job steps in this state on Schedd machines of
            this machine group.

   ReservationPermitted
            Indicates whether or not the node can be reserved. It is
            displayed as T or F (true or false).

   Running steps
            The number of job steps currently running on all startd
            machines of this machine group.

   Running Tasks
            The number of initiators used by the startd daemon to run
            LoadLeveler jobs. One initiator is used for each serial job
            step. One initiator is used for each task of a parallel job
            step. For the machine group's long listing, it represents
            the number of initiators used by all the startd daemons in
            the machine group.

   ScheddAvail
            A number indicating the number of Schedd machines in this
            machine group.

   ScheddRunning
            The number of job steps submitted to the Schedd machines of
            this machine group that are running somewhere in the
            LoadLeveler cluster.

   ScheddState
            The state of the Schedd daemon on this machine, which can be
            one of the following: 

            *  Down (number)
            *  Drned (Drained) (number)
            *  Drning (Draining) (number)
            *  Avail (Available) (number)

            where: number is the number of Schedds in corresponding
            states within the machine group.

   Speed    The speed associated with the machines in this machine
            group.

   StartdAvail
            A number indicating the number of startds in this machine
            group.

   Starting The number of job steps in this state on Schedd machines of
            this machine group.

   State    The state of the startd daemon, which can be: 

            *  Busy (number)
            *  Down (number)
            *  Drained (number)
            *  Draining (number)
            *  Flush (number)
            *  Idle (number)
            *  None (number)
            *  Running (number)
            *  Suspend (number)             

            where: number is the number of startds in corresponding
            states within the machine group.            

            For more information, see the "The startd daemon" topic 
            in LoadLeveler: Resource Manager.


   Total Jobs
            The number of jobs steps submitted to Schedd machines of
            this machine group.

   Unexpanded
            The number of job steps in this state on Schedd machines of
            this machine group.

6. This example generates the cluster-level long listing:

   llrstatus -L cluster -l    

   Or alternatively, set the environment variable
   LOADL_STATUS_LEVEL=cluster and issue: 

   llrstatus -l    

   You should receive output similar to the following:

   Name                       Schedd  Startd
   x330n51.clusters.com       Down    Run
   cnbladel1n10.clusters.com  Avail   Down
   cnbladel1n7.clusters.com   Avail   Suspend
   cnbladel1n8.clusters.com   Avail   Suspend
   cnbladel1n9.clusters.com   Avail   Suspend
   
   90 machines are absent:
         x330n51.clusters.com
         pccluster99.clusters.com
         pccluster141.clusters.com
         pccluster202.clusters.com
         .....
         .....
         bldaix09.clusters.com
   
   The Region Manager for cnblade11_region is defined on
         cnblade11n10.clusters.com, but is unusable.
   Alternate Region Manager is serving from cnblade11n1.clusters.com
   
   The Region Manager for pccluster_region is defined on
         pccluster100.clusters.com, but is unusable.
   There is no Region Manager serving pccluster_region.
   
   The Resource Manager is defined on percscm1.clusters.com

7. This example generates a listing of all of the consumable resources
   associated with all of the machines in the LoadLeveler cluster. 

   llrstatus -R    

   You should receive output similar to the following:    

   Machine                       Consumable Resource(Total)
   -------------------------     ------------------------------------------
   c209f1n01.ppd.pok.ibm.com     ConsumableCpus(4)+ ConsumableMemory
                                   (1.000 gb) n01_res(500)
   c209f1n02.ppd.pok.ibm.com     ConsumableCpus< 0 1 2 3 4 >n02_res(500) 
                                   Frame5(10)
   c209f1n05.ppd.pok.ibm.com     ConsumableCpus(4)+ ConsumableMemory
                                  (1.000 gb) spice2g6(360)
   
   c209f1n06.ppd.pok.ibm.com 			 CollectiveGroups (64)
   
   Resources with "+" appended to their names have the Total value reported 
   from Startd.

    
   -------------------------     ------------------------------------------
   c209f1n01.ppd.pok.ibm.com     ConsumableCpus(4)+ ConsumableMemory
                                   (1.000 gb) n01_res(500)
   c209f1n02.ppd.pok.ibm.com     ConsumableCpus< 0 1 2 3 4 >n02_res(500) 
                                   Frame5(10)
   c209f1n05.ppd.pok.ibm.com     ConsumableCpus(4)+ ConsumableMemory
                                  (1.000 gb) spice2g6(360)
   
   Resources with "+" appended to their names have the Total value reported 
   from Startd.

   Note:  The individual CPU ID < > notation will be used to list
   individual CPU IDs instead of the CPU count ( ) notation for machines
   where the RSET_SUPPORT configuration file keyword is set to
   RSET_MCM_AFFINITY. The CPU count ( ) notation will be used when the
   RSET_SUPPORT configuration file keyword is set to RSET_USER_DEFINED
   or RSET_NONE, or if this keyword is not specified in the
   configuration file.

8. This example generates a listing of information related to MCMs of
   machines in the LoadLeveler cluster. 
      
   llrstatus -M    

   You should receive output similar to the following:    

   Machine               MCM details 
   --------------------- -------------------------------------------------
   c890f14ec03.ppd.pok.ibm.com
                MCM0
                   Available Cpus :< 0-31 >(32)
                   Adapters       :
               	MCM1
                  	Available Cpus :< 32-63 >(32)
                  	Adapters       :network18338657682652659714 /
                                        [64,0 rCxt Blks]
            	                      network18338657682652659713 /
                                        [64,0 rCxt Blks]
                MCM2
            	      Available Cpus :< 64-95 >(32)
                   Adapters       :
           	    MCM3
                   Available Cpus :< 96-127 >(32)
            	      Adapters       :              	

    

   Note: The -M option will list the MCM information only when the
   RSET_SUPPORT configuration file keyword is set to RSET_MCM_AFFINITY.

9. This example generates a customized and formatted standard listing. 
      
   llrstatus -f %n %scs %inq %m %v %sts %l %o    

   You should receive output similar to the following:    

   Name             Schedd  InQ  Memory  FreeVMemory Startd LdAvg  OpSys
   ll5.pok.ibm.com  Avail   0    128     22708       Run    0.23   AIX71
   ll6.pok.ibm.com  Avail   3    224     16732       Run    0.51   AIX71
   
   R6000/AIX71             2 machines      3  jobs      3  running tasks
   Total Machines          2 machines      3  jobs      3  running tasks
   
   The Resource Manager is defined on 115.pok.ibm.com
   
   All machines on the machine_list are present.

10. This example generates a customized and unformatted (raw) standard
   listing. 

   Customized, Unformatted Standard Listing: A customized Output fields
   are separated by an exclamation point (!).    

   llrstatus -r %n %scs %inq %m %v %sts %l %o    

   You should receive output similar to the following:    

   ll5.pok.ibm.com!Avail!0!128!22688!Running!0.14!AIX71
   ll6.pok.ibm.com!Avail!3!224!16668!Running!0.37!AIX71

11. This example generates a listing containing information about the
   status of adapters associated with all of the machines in the
   LoadLeveler cluster: 

   llrstatus -a    

   You should receive output similar to the following:    

   ========================================================================
   c890f4ec05.ppd.pok.ibm.com
   iba0(InfiniBand,,,10.0.0.53,-1,0,0 rCxt Blks,01,)
   iba1(InfiniBand,,,10.0.0.53,-1,0,0 rCxt Blks,11,)
   network1833865768265265971s(striped,ml0,10.0.0.53,,-1,0,0 rCxt Blks,
      0111,)
   network18338657682652659713(aggregate,,,10.0.0.53,-1,0,0 rCxt Blks,0,)
   ib0(InfiniBand,192.168.8.53,192.168.8.53,10.0.0.53,158486581,64,
      0 rCxt Blks,0,,ErrDown,HB_UP,ErrDown,1,MCM0)
   network18338657682652659714(aggregate,,,10.0.0.53,-1,64,0 rCxt Blks,1,)
   ib1(InfiniBand,192.168.9.53,192.168.9.53,10.0.0.53,158486581,64,
      0 rCxt Blks,1,,READY,HB_UP,READY,2,MCM0)
   network18338657682652659715(aggregate,,,10.0.0.53,-1,64,0 rCxt Blks,1,)
   ib2(InfiniBand,192.168.10.53,192.168.10.53,10.0.0.53,158486581,64,
      0 rCxt Blks,1,,READY,HB_UP,READY,1,MCM1)
   network18338657682652659716(aggregate,,,10.0.0.53,-1,64,0 rCxt Blks,1,)
   ib3(InfiniBand,192.168.11.53,192.168.11.53,10.0.0.53,158486581,64,
      0 rCxt Blks,1,,READY,HB_UP,READY,2,MCM1)
   en0(ethernet,c890f4ec05.ppd.pok.ibm.com,9.114.80.53,,READY,HB_UP,READY)
   ml0(multilink,10.0.0.53,10.0.0.53,,READY,HB_UP,READY)
   
   ========================================================================
   c890f4ec04.ppd.pok.ibm.com
   iba0(InfiniBand,,,,-1,0,0 rCxt Blks,11,)
   iba1(InfiniBand,,,,-1,0,0 rCxt Blks,11,)
   network1833865768265265971s(striped,ml0,10.0.0.52,,-1,64,0 rCxt Blks,
      1111,)
   network18338657682652659713(aggregate,,,10.0.0.52,-1,64,0 rCxt Blks,1,)
   ib0(InfiniBand,192.168.8.52,192.168.8.52,10.0.0.52,158486580,64,
      0 rCxt Blks,1,,READY,HB_UP,READY,1,MCM0)
   network18338657682652659714(aggregate,,,10.0.0.52,-1,64,0 rCxt Blks,1,)
   ib1(InfiniBand,192.168.9.52,192.168.9.52,10.0.0.52,158486580,64,
      0 rCxt Blks,1,,READY,HB_UP,READY,2,MCM0)
   network18338657682652659715(aggregate,,,10.0.0.52,-1,64,0 rCxt Blks,1,)
   ib2(InfiniBand,192.168.10.52,192.168.10.52,10.0.0.52,158486580,64,
      0 rCxt Blks,1,,READY,HB_UP,READY,1,MCM1)
   network18338657682652659716(aggregate,,,10.0.0.52,-1,64,0 rCxt Blks,1,)
   ib3(InfiniBand,192.168.11.52,192.168.11.52,10.0.0.52,158486580,64,
      0 rCxt Blks,1,,READY,HB_UP,READY,2,MCM1)
   en0(ethernet,c890f4ec04.ppd.pok.ibm.com,9.114.80.52,,READY,HB_UP,READY)
   ml0(multilink,10.0.0.52,10.0.0.52,,READY,HB_UP,READY)

    
   *  For HFI adapters, the information format is:

      adapter_name(network_type, interface_name, interface_address, 
      multilink_address,switch_node_number or adapter_logical_id, 
      total_adapter_windows, total rCxt blocks,total Imme Send Buffers, 
      adapter_fabric_connectivity, config_state, heartbeat_state,adapter_state, 
      port_number, MCM_id)       

      For example: 

      network8078501872035430s(striped,,,,-1,440, 
         0 rCxt Blks, 256 Imm Send Buffers1,READY)
      network80785018720354304(aggregate,,,,-1,440,
         0 rCxt Blks, 256 Imm Send Buffers,1,READY)
      hf1(hfi,21.8.6.1,21.8.6.1,,0,220,
         0 rCxt Blks,128 Imm Send Buffers,
         1,READY,READY,HB_UNKNOWN,READY,,,MCM-1)
      hf0(hfi,20.8.6.1,20.8.6.1,,0,220,
         0 rCxt Blks,128 Imm Send Buffers,
         1,READY,READY,HB_UNKNOWN,READY,,,MCM-1)
      en0(ethernet,c250f08c06ap01.ppd.pok.ibm.com,10.8.6.1,,READY,HB_UNKNOWN,READY)

   *  For a switch adapter, the information format is: 

      adapter_name(network_type, interface_name, interface_address,
      multilink_address, switch_node_number or adapter_logical_id,
      total_adapter_windows, total rCxt blocks,
      adapter_fabric_connectivity)       

      For example:       

      iba0(InfiniBand,,,,-1,0,0 rCxt Blks,11,)
      network1833865768265265971s(striped,ml0,10.0.0.52,,-1,64,
         0 rCxt Blks,1111,)
      network18338657682652659713(aggregate,,,10.0.0.52,-1,64,0 rCxt Blks,1,)       

      Note that InfiniBand adapters contain additional information. The
      format is: 

      adapter_name(network_type, interface_name, interface_address,
      multilink_address, switch_node_number or adapter_logical_id,
      total_adapter_windows, total rCxt blocks, adapter_fabric_connectivity,
      config_state, heartbeat_state, adapter_state, port_number, MCM_id)

       For example: 

      ib0(InfiniBand,192.168.8.52,192.168.8.52,10.0.0.52,158486580,64,
      0 rCxt Blks,1,,READY,HB_UP,READY,1,MCM0)

   *  For non-switch adapters, the format is: 

      adapter_name(network_type, interface_name, interface_address, 
      multilink_address, config_state, heartbeat_state, adapter_state)       

      For example: 

      en0(ethernet,c197blade8b09.ppd.pok.ibm.com,9.114.198.233,,
      READY,HB_UP, READY)

   *  For InfiniBand, this example displays the port number on each
      InfiniBand adapter. The llrstatus command does not show port
      information for adapters that are not InfiniBand adapters: 

      llrstatus -a       

      You should receive output similar to the following:       

      ========================================================================
      c890f4ec05.ppd.pok.ibm.com
      iba0(InfiniBand,,,10.0.0.53,-1,0,0 rCxt Blks,01,)
      iba1(InfiniBand,,,10.0.0.53,-1,0,0 rCxt Blks,11,)
      network1833865768265265971s(striped,ml0,10.0.0.53,,-1,0,
         0 rCxt Blks,0111,)
      network18338657682652659713(aggregate,,,10.0.0.53,-1,0,0 rCxt Blks,0,)
      ib0(InfiniBand,192.168.8.53,192.168.8.53,10.0.0.53,158486581,64,
         0 rCxt Blks,0,,ErrDown,HB_UP,ErrDown,1,MCM0)
      network18338657682652659714(aggregate,,,10.0.0.53,-1,64,0 rCxt Blks,1,)
      ib1(InfiniBand,192.168.9.53,192.168.9.53,10.0.0.53,158486581,64,
         0 rCxt Blks,1,,READY,HB_UP,READY,2,MCM0)
      network18338657682652659715(aggregate,,,10.0.0.53,-1,64,0 rCxt Blks,1,)
      ib2(InfiniBand,192.168.10.53,192.168.10.53,10.0.0.53,158486581,64, 
         0 rCxt Blks,1,,READY,HB_UP,READY,1,MCM1)
      network18338657682652659716(aggregate,,,10.0.0.53,-1,64,0 rCxt Blks,1,)
      ib3(InfiniBand,192.168.11.53,192.168.11.53,10.0.0.53,158486581,64, 
         0 rCxt Blks,1,,READY,HB_UP,READY,2,MCM1)
      en0(ethernet,c890f4ec05.ppd.pok.ibm.com,9.114.80.53,,READY,HB_UP,READY)
      ml0(multilink,10.0.0.53,10.0.0.53,,READY,HB_UP,READY)
      
      ========================================================================
      c890f4ec04.ppd.pok.ibm.com
      iba0(InfiniBand,,,,-1,0,0 rCxt Blks,11,)
      iba1(InfiniBand,,,,-1,0,0 rCxt Blks,11,)
      network1833865768265265971s(striped,ml0,10.0.0.52,,-1,64,
         0 rCxt Blks,1111,)
      network18338657682652659713(aggregate,,,10.0.0.52,-1,64,0 rCxt Blks,1,)
      ib0(InfiniBand,192.168.8.52,192.168.8.52,10.0.0.52,158486580,64,
         0 rCxt Blks,1,,READY,HB_UP,READY,1,MCM0)
      network18338657682652659714(aggregate,,,10.0.0.52,-1,64,0 rCxt Blks,1,)
      ib1(InfiniBand,192.168.9.52,192.168.9.52,10.0.0.52,158486580,64,
         0 rCxt Blks,1,,READY,HB_UP,READY,2,MCM0)
      network18338657682652659715(aggregate,,,10.0.0.52,-1,64,0 rCxt Blks,1,)
      ib2(InfiniBand,192.168.10.52,192.168.10.52,10.0.0.52,158486580,64,
         0 rCxt Blks,1,,READY,HB_UP,READY,1,MCM1)
      network18338657682652659716(aggregate,,,10.0.0.52,-1,64,0 rCxt Blks,1,)
      ib3(InfiniBand,192.168.11.52,192.168.11.52,10.0.0.52,158486580,64, 
         0 rCxt Blks,1,,READY,HB_UP,READY,2,MCM1)
      en0(ethernet,c890f4ec04.ppd.pok.ibm.com,9.114.80.52,,READY,HB_UP,READY)
      ml0(multilink,10.0.0.52,10.0.0.52,,READY,HB_UP,READY)

12. The following example shows output for the llrstatus -l command that
   displays the SMT state for the machine: 

   ========================================================================
        Name = devf1n01.clusters.com
     Machine = devf1n01.clusters.com
        Arch = ppc64
       OpSys = Linux2
   .
   .
   .
     Feature = SMT
   .
   .
   .
         SMT = Enabled | Disabled | Not Supported
   TimeStamp = Fri 23 Jan 2009 04:44:06 PM CST
   .
   .
   .  

13. On a system that has one InfiniBand adapter and multiple MCMs, the
   llrstatus -a or llrstatus -M command displays the InfiniBand network
   interfaces connected to only one MCM. Processors in the other MCMs,
   however, can still communicate through the same network interfaces. 

   *  For example, if you issue: 

      llrstatus -a c395f2n02       

      You should receive output similar to the following:       

      ========================================================================
      c395f3n07.ppd.pok.ibm.com
      iba0(InfiniBand,,,,-1,0,0 rCxt Blks,11,)
      network1833865768265265971s(striped,ml0,192.168.200.22,,-1,64,
         0 rCxt Blks,11,)
      network18338657682652659713(aggregate,,,192.168.200.22,-1,64,
         0 rCxt Blks,1,)
      ib0(InfiniBand,c395f3n07ib0,192.168.100.22,192.168.200.22,158473815,64,
         0 rCxt Blks,1,,READY,HB_UP,READY,1,MCM1)
      network18338657682652659714(aggregate,,,192.168.200.22,-1,64,
         0 rCxt Blks,1,)
      ib1(InfiniBand,c395f3n07ib1,192.168.101.22,192.168.200.22,158473815,64,
         0 rCxt Blks,1,,READY,HB_UP,READY,2,MCM1)
      en0(ethernet,c395f3n07.ppd.pok.ibm.com,9.114.30.87,,READY,HB_UP,READY)
      ml0(multilink,c395f3n07ml0,192.168.200.22,,READY,HB_UP,READY)

   *  For example, if you issue: 

      llrstatus -M c395f2n02       

      You should receive output similar to the following:       

      Machine               MCM details
      --------------------- --------------------------------------------------
      c395f2n02.ppd.pok.ibm.com
            MCM0
               Available Cpus :< 0-3 >(4)
               Adapters       :
            MCM1
               Available Cpus :< 4-7 >(4)
               Adapters       :network18338657682652659713[64,0 rCxt Blks]
                               network18338657682652659714[64,0 rCxt Blks]
            MCM2
               Available Cpus :< 8-11 >(4)
               Adapters       :
            MCM3
               Available Cpus :< 12-15 >(4)
               Adapters       :
             

14. To display energy coefficients information, issue:

   llrstatus -e     

   You should receive output similar to the following:

   Frequency: 2.73 GHZ
   Coefficients: A = 4.0 B = 11.7 C = 3477.6 D = 3.9 E = 7.2 F = 2639.0
   
   Frequency: 2.56 GHZ
   Coefficients: A = 5.0 B = 11.0 C = 3200.0 D = 3.0 E = 6.2 F = 2600.0
   
   Frequency: 2.31 GHZ
   Coefficients: A = 4.0 B = 11.7 C = 3477.6 D = 3.9 E = 7.2 F = 2639.0
   
   Frequency: 2.27 GHZ
   Coefficients: A = 5.0 B = 11.0 C = 3200.0 D = 3.0 E = 6.2 F = 2600.0


Security


LoadLeveler administrators and users can issue this command.

