#!/bin/sh
# This script is used by the xCAT postscript process to configure the LoadLeveler 
# database server nodes when running LoadLeveler with the database option. The 
# management server node should have already initialized the LoadLeveler database 
# using the llconfig -i command prior to executing this script.
#
# sccs id = @(#) src/ll/db/scripts/llserver.sh, ll.db.gen, ll_rrnep2, rrnep21206a 1.2 10/20/10
#

POSTSCRIPT_PATH="LoadL"

UNAME=`uname -s`
if [[ ${UNAME} == "AIX" ]]; then
	ODBCINST="/usr/local/bin/odbcinst"
else
	ODBCINST="/usr/bin/odbcinst"
fi 

if [[ -f ${ODBCINST} ]]; then 
	MYUSER=`cat /etc/xcat/cfgloc 2> /dev/null | cut -d'|' -f2`
	MYPASS=`cat /etc/xcat/cfgloc 2> /dev/null | cut -d'|' -f3`

	if [[ -z $MYUSER || -z $MYPASS ]]; then
		echo "Could not parse the USER/PASSWORD from xCAT configuration file."
		echo "Verify that xCAT is installed and configured on this node"
		exit -1
	fi

	touch $POSTSCRIPT_PATH/odbc.ini.secure
	chmod 600 $POSTSCRIPT_PATH/odbc.ini.secure
	echo "USER = ${MYUSER}" > $POSTSCRIPT_PATH/odbc.ini.secure
	echo "PASSWORD = ${MYPASS}" >> $POSTSCRIPT_PATH/odbc.ini.secure

	if [[ -f ${POSTSCRIPT_PATH}/LoadL.cfg.server ]]; then 
		echo "Copying the LoadL.cfg file to /etc ... "
		/bin/cp ${POSTSCRIPT_PATH}/LoadL.cfg.server /etc/LoadL.cfg
		/bin/chmod 644 /etc/LoadL.cfg
	fi

else
	echo "ERROR: The file ${ODBCINST} is not avaiable on this machine.  Verify that unixODBC has been installed." 
	exit -1
fi

USER=`cat /etc/LoadL.cfg 2>> /dev/null | grep -i loadluserid | sed 's/ //g' | cut -d'=' -f2`
if [[ -z $USER ]]; then
	# if LoadL.cfg is not being used, default to the loadl user id
	USER="loadl"
fi
GROUP=`cat /etc/LoadL.cfg 2>> /dev/null | grep -i loadlgroupid | sed 's/ //g' | cut -d'=' -f2`
if [[ -z $GROUP ]]; then
	GROUP=`cat /etc/passwd 2>> /dev/null | grep "loadl:" | cut -d: -f4`
	if [[ -z $GROUP ]]; then 
		echo "ERROR: Cannot determine the group for the LoadLeveler default user: loadl.  Please verify that the loadl userid has been created."
		exit -1
	fi
fi

# Create the odbc entry for the user specified by LoadLUserID (or default to loadl if none specified)
if [[ -f $POSTSCRIPT_PATH/odbc.ini.user ]]; then 
	echo "Installing the user odbc.ini file for the LoadLUserID: ${USER}" 
	cp $POSTSCRIPT_PATH/odbc.ini.user $POSTSCRIPT_PATH/odbc.ini.user.tmp
	cat $POSTSCRIPT_PATH/odbc.ini.secure >> $POSTSCRIPT_PATH/odbc.ini.user.tmp
	/bin/su - ${USER} -c "${ODBCINST} -i -s -h -f `pwd`/$POSTSCRIPT_PATH/odbc.ini.user.tmp"
	/bin/rm -f $POSTSCRIPT_PATH/odbc.ini.user.tmp
fi

if [[ -f $POSTSCRIPT_PATH/odbc.ini.secure ]]; then
	/bin/rm $POSTSCRIPT_PATH/odbc.ini.secure
fi


# creating the log/spool/execute directories with the LoadLeveler
# user/group defined in LoadL.cfg, or defaulting to the loadl user id 
# and group found in /etc/passwd. The directories are created with 
# the following permissions:
#	log 	775
#	spool 	700 
# 	execute	1777

DIR_CONFIG_FILE="${POSTSCRIPT_PATH}/ll_config_directories"

while read line
do
	echo "Creating directory: $line"
	eval "/bin/mkdir -p $line"
	eval "/bin/chmod 777 $line"
	eval "/bin/chown -R ${USER}:${GROUP} $line"

	KW=${line##*/}
	if [[ ${KW} == "log" ]] ; then 
		eval "/bin/chmod 775 $line"
	elif [[ ${KW} == "spool" ]] ; then 
		eval "/bin/chmod 700 $line"
	elif [[ ${KW} == "execute" ]] ; then 
		eval "/bin/chmod 1777 $line"
	else 
		echo "error processing line: $line"
		exit -1
	fi
done < ${DIR_CONFIG_FILE}

